ErrorIsFromTonicServerImpl

Trait ErrorIsFromTonicServerImpl 

pub trait ErrorIsFromTonicServerImpl
where Self: Error,
{ // Required method fn is_from_tonic_server_impl(&self) -> bool; }

Required Methods

fn is_from_tonic_server_impl(&self) -> bool

Returns whether the error is from the implementation of a tonic server, i.e., created with ToTonicStatus::to_status.

This does not count errors initiated from the library, typically connection issues. As a result, this function can be used to decide whether an error should be retried.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors